export { KeyValueStorageService, KeyValueStorage, type KeyValueStats, type KeyValueStatsPaginated, type KeyValueItemWithMetadata, type DataResult, type DataResultFound, type DataResultNotFound, type KeyValueStorageSetParams, type CreateNamespaceParams, type GetAllStatsParams, type KVSortField, KV_MIN_TTL_SECONDS, KV_MAX_TTL_SECONDS, KV_DEFAULT_TTL_SECONDS, DataResultFoundSchema, DataResultNotFoundSchema, DataResultSchema, KeyValueStorageSetParamsSchema, CreateNamespaceParamsSchema, GetAllStatsParamsSchema, KeyValueStatsSchema, KeyValueStatsPaginatedSchema, KeyValueItemWithMetadataSchema, KVSortFieldSchema, } from '@agentuity/core/keyvalue';
import { KeyValueStorageService, type KeyValueStorageSetParams, type DataResult } from '@agentuity/core/keyvalue';
import { type Logger } from '@agentuity/adapter';
import { z } from 'zod';
export declare const KeyValueClientOptionsSchema: z.ZodObject<{
    apiKey: z.ZodOptional<z.ZodString>;
    url: z.ZodOptional<z.ZodString>;
    orgId: z.ZodOptional<z.ZodString>;
    logger: z.ZodOptional<z.ZodCustom<Logger, Logger>>;
}, z.core.$strip>;
export type KeyValueClientOptions = z.infer<typeof KeyValueClientOptionsSchema>;
export declare class KeyValueClient {
    #private;
    constructor(options?: KeyValueClientOptions);
    get<T>(name: string, key: string): Promise<DataResult<T>>;
    set<T = unknown>(name: string, key: string, value: T, params?: KeyValueStorageSetParams): Promise<void>;
    delete(name: string, key: string): Promise<void>;
    getStats(name: string): Promise<{
        sum: number;
        count: number;
        createdAt?: number | undefined;
        lastUsedAt?: number | undefined;
        internal?: boolean | undefined;
    }>;
    getAllStats(params?: Parameters<KeyValueStorageService['getAllStats']>[0]): Promise<Record<string, {
        sum: number;
        count: number;
        createdAt?: number | undefined;
        lastUsedAt?: number | undefined;
        internal?: boolean | undefined;
    }> | {
        namespaces: Record<string, {
            sum: number;
            count: number;
            createdAt?: number | undefined;
            lastUsedAt?: number | undefined;
            internal?: boolean | undefined;
        }>;
        total: number;
        limit: number;
        offset: number;
        hasMore: boolean;
    }>;
    getNamespaces(): Promise<string[]>;
    search<T = unknown>(name: string, keyword: string): Promise<Map<string, import("@agentuity/core").KeyValueItemWithMetadata<T>>>;
    getKeys(name: string): Promise<string[]>;
    deleteNamespace(name: string): Promise<void>;
    createNamespace(name: string, params?: Parameters<KeyValueStorageService['createNamespace']>[1]): Promise<void>;
}
//# sourceMappingURL=index.d.ts.map